@@ -1,12 +1,13 @@
 package data
 
 import (
+	"context"
 	"strings"
 
 	"github.com/hairyhenderson/gomplate/v3/env"
 )
 
-func readEnv(source *Source, args ...string) (b []byte, err error) {
+func readEnv(ctx context.Context, source *Source, args ...string) (b []byte, err error) {
 	n := source.URL.Path
 	n = strings.TrimPrefix(n, "/")
 	if n == "" {
